==> leechcraft-0.3.65.tar.bz2: leechcraft-0.3.65/src/plugins/seekthru/leechcraft_seekthru_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::SeekThru::Core</name>
    <message>
        <location filename="core.cpp" line="45"/>
        <source>Short name</source>
        <translation>Короткое имя</translation>
    </message>
    <message>
        <location filename="core.cpp" line="109"/>
        <source>Open</source>
        <translation>Открытый</translation>
    </message>
    <message>
        <location filename="core.cpp" line="111"/>
        <source>Limited</source>
        <translation>Ограниченный</translation>
    </message>
    <message>
        <location filename="core.cpp" line="113"/>
        <source>Private</source>
        <translation>Частный</translation>
    </message>
    <message>
        <location filename="core.cpp" line="115"/>
        <source>Closed</source>
        <translation>Закрытый</translation>
    </message>
    <message>
        <location filename="core.cpp" line="195"/>
        <source>%1 wasn&apos;t delegated</source>
        <translation>%1 не был делегирован</translation>
    </message>
    <message>
        <location filename="core.cpp" line="303"/>
        <source>Could not open file %1.</source>
        <translation>Невозможно открыть файл %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="313"/>
        <source>Could not remove temporary file %1.</source>
        <translation>Невозможно удалить временный файл %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="321"/>
        <source>A job was delegated, but it failed.</source>
        <translation>Задача была делегирована неудачно.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="373"/>
        <source>XML parse error %1 at %2:%3.</source>
        <translation>Ошибка парсинга XML %1 в %2:%3.</translation>
    </message>
    <message>
        <source>Not and OpenSearch description.</source>
        <translation type="obsolete">Не OpenSearch-описание.</translation>
    </message>
    <message>
        <source>Malformed OpenSearch description.</source>
        <translation type="obsolete">Плохо сформированное OpenSearch-описание.</translation>
    </message>
    <message>
        <source>Enter categories</source>
        <translation type="obsolete">Введите категории</translation>
    </message>
    <message>
        <source>Please enter categories for this searcher:</source>
        <translation type="obsolete">Пожалуйста, введите категории для этого поисковика:</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchHandler</name>
    <message>
        <location filename="searchhandler.cpp" line="48"/>
        <source>Subscribe</source>
        <translation>Подписаться</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="73"/>
        <source>%1 total results</source>
        <translation>%1 результатов всего</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="76"/>
        <source>Unknown number of results</source>
        <translation>Неизвестное количество результатов</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="83"/>
        <source> (RSS)</source>
        <translation>(RSS)</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="86"/>
        <source> (Atom)</source>
        <translation>(Atom)</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="89"/>
        <source> (HTML)</source>
        <translation>(HTML)</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="216"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation>Задача для запроса&lt;br /&gt;%1&lt;br /&gt;не была делегирована.</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="240"/>
        <source>Could not open file %1.</source>
        <translation>Невозможно открыть файл %1.</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="251"/>
        <source>Could not remove temporary file %1.</source>
        <translation>Невозможно удалить временный файл %1.</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="295"/>
        <source>Search request for URL&lt;br /&gt;%1&lt;br /&gt;was delegated, but it failed.</source>
        <translation>Поисковый запрос к URL&lt;br /&gt;%1&lt;br /&gt;был делегирван, но не удался.</translation>
    </message>
    <message>
        <source>A job was delegated, but it failed.</source>
        <translation type="obsolete">Задача была делегирована неудачно.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchersList</name>
    <message>
        <location filename="searcherslist.cpp" line="52"/>
        <source>No description</source>
        <translation>Нет описания</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="58"/>
        <source>No long name</source>
        <translation>Нет полного имени</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="68"/>
        <source>No contacts information</source>
        <translation>Нет контактной информации</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="74"/>
        <source>No developer information</source>
        <translation>Нет информации о разработчике</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="80"/>
        <source>No attribution information</source>
        <translation>Нет информации об авторстве</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="86"/>
        <source>No right information</source>
        <translation>Нет информации о правах</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="91"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="91"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="100"/>
        <source>Adding a new searcher</source>
        <translation>Добавление нового поисковика</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="101"/>
        <source>Enter the URL of the OpenSearch description</source>
        <translation>Введи URL OpenSearch-описания</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SeekThru</name>
    <message>
        <location filename="seekthru.cpp" line="83"/>
        <source>Search via OpenSearch-aware search providers.</source>
        <translation>Поиск при помощи OpenSearch-поисковиков.</translation>
    </message>
    <message>
        <location filename="seekthru.cpp" line="145"/>
        <location filename="seekthru.cpp" line="152"/>
        <source>LeechCraft</source>
        <translation>LeechCraft</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::StartupFirstPage</name>
    <message>
        <location filename="startupfirstpage.cpp" line="67"/>
        <source>SeekThru</source>
        <translation>SeekThru</translation>
    </message>
    <message>
        <location filename="startupfirstpage.cpp" line="68"/>
        <source>Select default search engines</source>
        <translation>Выбор поисковых систем по умолчанию</translation>
    </message>
</context>
<context>
    <name>SearchersList</name>
    <message>
        <location filename="searcherslist.ui" line="24"/>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="30"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="40"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="60"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="69"/>
        <source>Long name:</source>
        <translation>Длинное имя:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="83"/>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="93"/>
        <source>Tags:</source>
        <translation>Метки:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="100"/>
        <source>Contact:</source>
        <translation>Контакты:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="114"/>
        <source>Attribution:</source>
        <translation>Авторство:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="128"/>
        <source>Right:</source>
        <translation>Права:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="142"/>
        <source>Developer:</source>
        <translation>Разработчик:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="156"/>
        <source>Adult:</source>
        <translation>Контент для взрослых:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="170"/>
        <source>Languages:</source>
        <translation>Языки:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="14"/>
        <source>Searchers list</source>
        <translation>Список поисковиков</translation>
    </message>
</context>
<context>
    <name>StartupFirstPageWidget</name>
    <message>
        <location filename="startupfirstpage.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="22"/>
        <source>Localized set:</source>
        <translation>Локализованный набор:</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="30"/>
        <source>General</source>
        <translation>Общий</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="35"/>
        <source>Russian (ru)</source>
        <translation>Русский (ru)</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="59"/>
        <source>Engine</source>
        <translation>Движок</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="64"/>
        <source>Tags</source>
        <translation>Теги</translation>
    </message>
</context>
<context>
    <name>TagsAsker</name>
    <message>
        <location filename="tagsasker.ui" line="14"/>
        <source>LeechCraft</source>
        <translation>LeechCraft</translation>
    </message>
    <message>
        <location filename="tagsasker.ui" line="22"/>
        <source>Tags for this searcher:</source>
        <translation>Теги для этого движка:</translation>
    </message>
</context>
</TS>

==> leechcraft-0.3.80_rc20101221.tar.bz2: leechcraft-0.3.80_rc20101221/src/plugins/seekthru/leechcraft_seekthru_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::SeekThru::Core</name>
    <message>
        <location filename="core.cpp" line="81"/>
        <source>Short name</source>
        <translation>Короткое имя</translation>
    </message>
    <message>
        <location filename="core.cpp" line="123"/>
        <source>Open</source>
        <translation>Открытый</translation>
    </message>
    <message>
        <location filename="core.cpp" line="125"/>
        <source>Limited</source>
        <translation>Ограниченный</translation>
    </message>
    <message>
        <location filename="core.cpp" line="127"/>
        <source>Private</source>
        <translation>Частный</translation>
    </message>
    <message>
        <location filename="core.cpp" line="129"/>
        <source>Closed</source>
        <translation>Закрытый</translation>
    </message>
    <message>
        <location filename="core.cpp" line="274"/>
        <source>%1 wasn&apos;t delegated</source>
        <translation>%1 не был делегирован</translation>
    </message>
    <message>
        <location filename="core.cpp" line="410"/>
        <source>Could not open file %1.</source>
        <translation>Невозможно открыть файл %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="420"/>
        <source>Could not remove temporary file %1.</source>
        <translation>Невозможно удалить временный файл %1.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="428"/>
        <source>A job was delegated, but it failed.</source>
        <translation>Задача была делегирована неудачно.</translation>
    </message>
    <message>
        <location filename="core.cpp" line="480"/>
        <source>XML parse error %1 at %2:%3.</source>
        <translation>Ошибка парсинга XML %1 в %2:%3.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchHandler</name>
    <message>
        <location filename="searchhandler.cpp" line="49"/>
        <source>Subscribe</source>
        <translation>Подписаться</translation>
    </message>
    <message numerus="yes">
        <location filename="searchhandler.cpp" line="74"/>
        <source>%n total result(s)</source>
        <oldsource>%1 total results</oldsource>
        <translation>
            <numerusform>%n результат всего</numerusform>
            <numerusform>%n результата всего</numerusform>
            <numerusform>%n результатов всего</numerusform>
        </translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="76"/>
        <source>Unknown number of results</source>
        <translation>Неизвестное количество результатов</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="218"/>
        <source>Job for request&lt;br /&gt;%1&lt;br /&gt;wasn&apos;t delegated.</source>
        <translation>Задача для запроса&lt;br /&gt;%1&lt;br /&gt;не была делегирована.</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="242"/>
        <source>Could not open file %1.</source>
        <translation>Невозможно открыть файл %1.</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="253"/>
        <source>Could not remove temporary file %1.</source>
        <translation>Невозможно удалить временный файл %1.</translation>
    </message>
    <message>
        <location filename="searchhandler.cpp" line="297"/>
        <source>Search request for URL&lt;br /&gt;%1&lt;br /&gt;was delegated, but it failed.</source>
        <translation>Поисковый запрос к URL&lt;br /&gt;%1&lt;br /&gt;был делегирван, но не удался.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SearchersList</name>
    <message>
        <location filename="searcherslist.cpp" line="52"/>
        <source>No description</source>
        <translation>Нет описания</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="58"/>
        <source>No long name</source>
        <translation>Нет полного имени</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="68"/>
        <source>No contacts information</source>
        <translation>Нет контактной информации</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="74"/>
        <source>No developer information</source>
        <translation>Нет информации о разработчике</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="80"/>
        <source>No attribution information</source>
        <translation>Нет информации об авторстве</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="86"/>
        <source>No right information</source>
        <translation>Нет информации о правах</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="91"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="91"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="100"/>
        <source>Adding a new searcher</source>
        <translation>Добавление нового поисковика</translation>
    </message>
    <message>
        <location filename="searcherslist.cpp" line="101"/>
        <source>Enter the URL of the OpenSearch description</source>
        <translation>Введи URL OpenSearch-описания</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::SeekThru</name>
    <message>
        <location filename="seekthru.cpp" line="99"/>
        <source>Search via OpenSearch-aware search providers.</source>
        <translation>Поиск при помощи OpenSearch-поисковиков.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::SeekThru::StartupFirstPage</name>
    <message>
        <location filename="startupfirstpage.cpp" line="72"/>
        <source>Select default search engines</source>
        <translation>Выбор поисковых систем по умолчанию</translation>
    </message>
</context>
<context>
    <name>SearchersList</name>
    <message>
        <location filename="searcherslist.ui" line="14"/>
        <source>Searchers list</source>
        <translation>Список поисковиков</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="24"/>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="30"/>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="40"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="60"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="69"/>
        <source>Long name:</source>
        <translation>Полное имя:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="83"/>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="93"/>
        <source>Tags:</source>
        <translation>Теги:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="100"/>
        <source>Contact:</source>
        <translation>Контакты:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="114"/>
        <source>Attribution:</source>
        <translation>Авторство:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="128"/>
        <source>Right:</source>
        <translation>Права:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="142"/>
        <source>Developer:</source>
        <translation>Разработчик:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="156"/>
        <source>Adult:</source>
        <translation>Взрослость:</translation>
    </message>
    <message>
        <location filename="searcherslist.ui" line="170"/>
        <source>Languages:</source>
        <translation>Языки:</translation>
    </message>
</context>
<context>
    <name>SeekThruStartupFirstPageWidget</name>
    <message>
        <location filename="startupfirstpage.ui" line="22"/>
        <source>Localized set:</source>
        <translation>Локализованный набор:</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="30"/>
        <source>General</source>
        <translation>Общий</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="35"/>
        <source>Russian (ru)</source>
        <translation>Русский (ru)</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="59"/>
        <source>Engine</source>
        <translation>Поисковик</translation>
    </message>
    <message>
        <location filename="startupfirstpage.ui" line="64"/>
        <source>Tags</source>
        <translation>Теги</translation>
    </message>
</context>
<context>
    <name>TagsAsker</name>
    <message>
        <location filename="tagsasker.ui" line="22"/>
        <source>Tags for this searcher:</source>
        <translation>Теги для этого поисковика:</translation>
    </message>
</context>
<context>
    <name>seekthrusettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>SeekThru settings</source>
        <translation>Настройки SeekThru</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <location filename="dummy.cpp" line="4"/>
        <source>Searchers</source>
        <translation>Поисковики</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Navigation bar visible</source>
        <translation>Отображать навигационную панель</translation>
    </message>
</context>
</TS>
